@@ -2,7 +2,7 @@ use 5.14.0;
 
 package Dist::Zilla::Plugin::MapMetro::MintMetroFile;
 
-our $VERSION = '0.1402'; # VERSION
+our $VERSION = '0.1500'; # VERSION
 
 use Moose;
 with 'Dist::Zilla::Role::FileGatherer';
@@ -48,15 +48,15 @@ Dist::Zilla::Plugin::MapMetro::MintMetroFile
 
 =head1 VERSION
 
-Version 0.1402, released 2015-01-29.
+Version 0.1500, released 2015-02-01.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/Csson/p5-Dist-Zilla-MintingProfile-MapMetro-Map>.
+L<https://github.com/Csson/p5-Dist-Zilla-MintingProfile-MapMetro-Map>
 
 =head1 HOMEPAGE
 
-Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla-MintingProfile-MapMetro-Map>.
+L<https://metacpan.org/release/Dist-Zilla-MintingProfile-MapMetro-Map>
 
 =head1 AUTHOR
 
